#' rdss package
#'
#' Companion datasets and functions for the book "Research Design in the Social Sciences: Declaration, Diagnosis, and Redesign" (book.declaredesign.org)
#'
#' @name rdss
"_PACKAGE"

#' @importFrom generics tidy
#' @export
generics::tidy

utils::globalVariables(c("X", "variance", "estimate", "std.error", "value", "name", "order_by___", "state", "fitted", "PS_weight", "covariates", "pred", "type", "tau.squared", "tau.squared.se", "term", "ci.lb", "ci.ub", "Estimate", "Std. Err", "z value", "Pr(>|z|)", "Attribute", "Level", "profile", "attribute", "level", "partial", "conjoint_utility", "subject", "task", "U", "XY"))

